#
# spec file for package btfs
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) 2025 Andreas Stieger <Andreas.Stieger@gmx.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           btfs
Version:        3.1
Release:        1.1
Summary:        A BitTorrent file system based on FUSE
License:        GPL-3.0-or-later
URL:            https://github.com/johang/%{name}
Source:         https://github.com/johang/%{name}/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  c++_compiler
%if 0%{?suse_version} > 1500
BuildRequires:  libboost_system-devel
%else
BuildRequires:  libboost_system1_75_0-devel
%endif
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(fuse3) >= 3.0
BuildRequires:  pkgconfig(libcurl) >= 7.22.0
BuildRequires:  pkgconfig(libtorrent-rasterbar) >= 1.0.0

%description
With BTFS, you can mount any .torrent file or magnet link and then use it as
any read-only directory in your file tree. The contents of the files will be
downloaded on-demand as they are read by applications. Tools like ls, cat and
cp work as expected. Applications like media players can also work without changes.

%prep
%autosetup -p1
sed -i 's,env python,python,' scripts/btplay

%build
export CXXFLAGS="-std=c++14"
autoreconf -fi
%configure
%make_build

%install
%make_install V=1

%files
%doc README.md
%license LICENSE
%{_mandir}/man1/%{name}.1%{?ext_man}
%{_bindir}/btfs
%{_bindir}/btplay
%{_bindir}/btfsstat

%changelog
* Mon May 12 2025 Andreas Stieger <andreas.stieger@gmx.de>
- update to 3.1:
  * Add command-line option to disable logs
  * port to fuse 3 (boo#1243039)
* Fri Apr 19 2024 Luigi Baldoni <aloisio@gmx.com>
- Build against boost 1.75 on Leap 15 to match the one used by
  libtorrent-rasterbar (code-o-o#leap/features/issue/155)
* Sun Feb 14 2021 Mia Herkt <mia@0x0.st>
- 2.24
  * use XDG_DATA_HOME if defined
* Sun Nov 22 2020 Mia Herkt <mia@0x0.st>
- 2.23
  * Add --utp-only flag to disable TCP
* Fri Sep 11 2020 Luigi Baldoni <aloisio@gmx.com>
- Fix build with libtorrent v2.
- Spec cleanup
* Thu Aug 13 2020 Paolo Stivanin <info@paolostivanin.com>
- 2.22
  * bug fixes
* Thu Oct 17 2019 Richard Brown <rbrown@suse.com>
- Remove obsolete Groups tag (fate#326485)
* Wed Aug 28 2019 Martin Herkt <9+suse@cirno.systems>
- 2.20
  * btplay: Change shebang to python3
* Sun Apr 14 2019 Martin Herkt <9+suse@cirno.systems>
- Modernize spec file
- 2.19
  * Add option to set data directory
* Mon Nov 27 2017 9@cirno.systems
- 2.18
  * Force DHT announce when bootstrap completes
  * Don't set file priority to 0 at start
  * Fix delete-on-unmount
  * Remove unneeded debug prints
  * Fix a potential null pointer deref
  * Silence warning on libtorrent 1.2
* Mon Sep 11 2017 9@cirno.systems
- 2.17
  * Adjust to libtorrent 1.2 API changes
    + Session flags changed type.
    + Remove flags changed type.
  * Silence warning about deprecated flags in libtorrent 1.2
  * Tweak configure.ac
  * Handle read_piece_alert errors
    + Fixes segfault, upstream bug #42
  * Set request timeout
* Wed Aug 23 2017 9@cirno.systems
- 2.16
  * Implement listxattr and getxattr
  * Return IS_BTFS xattr on all files and directories
  * Add btfsstat program
* Fri Aug  4 2017 9@cirno.systems
- 2.15
  * Adjust to libtorrent 1.2 API changes
    + Alert notification categories changed type
    + torrent_handle::status() parameter changed type
  * Set correct block usage
    (so tools like "du" report correct disk usage)
  * Implement statfs callback
    (so tools like "df" report torrent size and download progress)
* Thu Jul 27 2017 9@cirno.systems
- 2.14
  * Adjust to libtorrent API changes (add_dht_router deprecated)
  * Make it build with libtorrent 1.2 (drops support for 0.16)
* Sun Jun 18 2017 9@cirno.systems
- Initial commit, 2.13
